Learn R Programming

colorr (version 1.1.0)

colorr.leagues: Leagues covered by colorr

Description

Returns the league codes colorr knows about. Every code is a valid league argument to colorr.teams, colorr.colors and colorr.pal. The pseudo-league "soccer" is also accepted by those functions and pools every soccer league into a single namespace.

Usage

colorr.leagues(soccer_only = FALSE)

Value

Character vector of league codes.

Arguments

soccer_only

Logical. If TRUE, return only the soccer leagues.

Author

Charles Crabtree [email protected]

Examples

Run this code
colorr.leagues()
colorr.leagues(soccer_only = TRUE)

Run the code above in your browser using DataLab