powered by
Returns the league codes colorr knows about. Every code is a valid league argument to colorr.teams, colorr.colors and colorr.pal. The pseudo-league "soccer" is also accepted by those functions and pools every soccer league into a single namespace.
league
colorr.teams
colorr.colors
colorr.pal
"soccer"
colorr.leagues(soccer_only = FALSE)
Character vector of league codes.
Logical. If TRUE, return only the soccer leagues.
TRUE
Charles Crabtree [email protected]
colorr.leagues() colorr.leagues(soccer_only = TRUE)
Run the code above in your browser using DataLab