| epl-scales | R Documentation |
Colour and fill scales that take their colors from an EPL team, the
ggplot2 counterpart of epl.colors. scale_color_epl is an alias for
scale_colour_epl.
scale_colour_epl(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
scale_color_epl(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
scale_fill_epl(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
set |
Character string naming an EPL team. See |
discrete |
Logical. |
reverse |
Logical. If |
legacy |
Logical. If |
... |
Passed on to |
A ggplot2 scale, to be added to a plot with +.
Charles Crabtree charles.crabtree@monash.edu
epl.colors for the raw palette, colorr.pal for the
palette function.
library(ggplot2)
ggplot(mtcars, aes(factor(cyl), mpg, fill = factor(cyl))) +
geom_boxplot() +
scale_fill_epl("man_united") # Manchester United
ggplot(mtcars, aes(wt, mpg, colour = hp)) +
geom_point(size = 3) +
scale_colour_epl("man_united", discrete = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.