| nba-scales | R Documentation |
Colour and fill scales that take their colors from an NBA team, the
ggplot2 counterpart of nba.colors. scale_color_nba is an alias for
scale_colour_nba.
scale_colour_nba(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
scale_color_nba(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
scale_fill_nba(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
set |
Character string naming an NBA team. See |
discrete |
Logical. |
reverse |
Logical. If |
legacy |
Logical. If |
... |
Passed on to |
A ggplot2 scale, to be added to a plot with +.
Charles Crabtree charles.crabtree@monash.edu
nba.colors for the raw palette, colorr.pal for the
palette function.
library(ggplot2)
ggplot(mtcars, aes(factor(cyl), mpg, fill = factor(cyl))) +
geom_boxplot() +
scale_fill_nba("bucks") # Milwaukee Bucks
ggplot(mtcars, aes(wt, mpg, colour = hp)) +
geom_point(size = 3) +
scale_colour_nba("bucks", discrete = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.