| nhl-scales | R Documentation |
Colour and fill scales that take their colors from an NHL team, the
ggplot2 counterpart of nhl.colors. scale_color_nhl is an alias for
scale_colour_nhl.
scale_colour_nhl(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
scale_color_nhl(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
scale_fill_nhl(set, discrete = TRUE, reverse = FALSE, legacy = FALSE, ...)
set |
Character string naming an NHL team. See |
discrete |
Logical. |
reverse |
Logical. If |
legacy |
Logical. If |
... |
Passed on to |
A ggplot2 scale, to be added to a plot with +.
Charles Crabtree charles.crabtree@monash.edu
nhl.colors for the raw palette, colorr.pal for the
palette function.
library(ggplot2)
ggplot(mtcars, aes(factor(cyl), mpg, fill = factor(cyl))) +
geom_boxplot() +
scale_fill_nhl("kraken") # Seattle Kraken
ggplot(mtcars, aes(wt, mpg, colour = hp)) +
geom_point(size = 3) +
scale_colour_nhl("kraken", discrete = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.